==> nextcloud-20.0.8p0.tgz: nextcloud/apps/user_status/l10n/sv.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Senaste statusuppdateringar",
    "In a meeting" : "På ett möte",
    "Commuting" : "Reser",
    "Out sick" : "Sjuk",
    "Vacationing" : "På semester",
    "Working remotely" : "Arbetar hemifrån",
    "User status" : "Användarstatus",
    "Clear status message after" : "Rensa statusmeddelande efter",
    "What's your status?" : "Vad är din status?",
    "Set status" : "Sätt status",
    "Online status" : "Online-status",
    "Status message" : "Statusmeddelande",
    "Clear status message" : "Rensa statusmeddelande",
    "Set status message" : "Sätt statusmeddelande",
    "There was an error saving the status" : "Ett fel inträffade när statusen skulle ändras",
    "There was an error clearing the status" : "Ett fel inträffade när statusen skulle rensas",
    "No recent status changes" : "Inga statusuppdateringar den sista tiden",
    "Away" : "Iväg",
    "Do not disturb" : "Stör ej",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Rensa inte",
    "Today" : "Idag",
    "This week" : "Denna vecka",
    "Online" : "Online",
    "Invisible" : "Osynlig",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ett fel inträffade när den nya statusen skulle sparas",
    "30 minutes" : "30 minuter",
    "1 hour" : "1 timme",
    "4 hours" : "4 timmar",
    "Mute all notifications" : "Dölj alla aviseringar",
    "Appear offline" : "Visa som offline",
    "Clear status after" : "Rensa status efter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.14.tgz: nextcloud/apps/user_status/l10n/sv.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Senaste statusuppdateringar",
    "In a meeting" : "På ett möte",
    "Commuting" : "Reser",
    "Out sick" : "Sjuk",
    "Vacationing" : "På semester",
    "Working remotely" : "Arbetar hemifrån",
    "User status" : "Användarstatus",
    "Clear status message after" : "Rensa statusmeddelande efter",
    "Set status" : "Sätt status",
    "Online status" : "Online-status",
    "Status message" : "Statusmeddelande",
    "Clear status message" : "Rensa statusmeddelande",
    "Set status message" : "Sätt statusmeddelande",
    "There was an error saving the status" : "Ett fel inträffade när statusen skulle ändras",
    "There was an error clearing the status" : "Ett fel inträffade när statusen skulle rensas",
    "No recent status changes" : "Inga statusuppdateringar den sista tiden",
    "Away" : "Iväg",
    "Do not disturb" : "Stör ej",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Rensa inte",
    "Today" : "Idag",
    "This week" : "Denna vecka",
    "Online" : "Online",
    "Invisible" : "Osynlig",
    "Offline" : "Frånkopplad",
    "There was an error saving the new status" : "Ett fel inträffade när den nya statusen skulle sparas",
    "30 minutes" : "30 minuter",
    "1 hour" : "1 timme",
    "4 hours" : "4 timmar",
    "Mute all notifications" : "Dölj alla aviseringar",
    "Appear offline" : "Visa som frånkopplad",
    "Clear status after" : "Rensa status efter",
    "What's your status?" : "Vad är din status?"
},
"nplurals=2; plural=(n != 1);");
